View source: R/build_examples.R
| build_examples | R Documentation |
Build the training examples for a regressive model to forecast a time series using lagged values of the series as autoregressive features.
build_examples(timeS, lags)
timeS |
The time series. |
lags |
An integer vector with the lags used as feature vector in decreasing order. |
A list with two fields: 1) a matrix with the features of the examples and 2) a vector with the targets of the examples
build_examples(ts(1:5), lags = 2:1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.